@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2020 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Box::Parser::Perl;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.010';
 
 use base 'Mail::Box::Parser';
 
+use strict;
+use warnings;
+
 use Mail::Message::Field;
 use List::Util 'sum';
 use IO::File;
@@ -130,7 +134,7 @@ sub readSeparator()
 
     return () unless defined $line;
 
-    $line     =~ s/[\012\015\n]+$/\n/g;
+    $line     =~ s/[\012\015]+$/\n/;
     return ($start, $line)
         if substr($line, 0, length $sep) eq $sep;
 
@@ -140,7 +144,6 @@ sub readSeparator()
 
 sub _read_stripped_lines(;$$)
 {   my ($self, $exp_chars, $exp_lines) = @_;
-    $exp_lines  = -1 unless defined $exp_lines;
     my @seps    = @{$self->{MBPP_separators}};
 
     my $file    = $self->{MBPP_file};
@@ -157,7 +160,9 @@ sub _read_stripped_lines(;$$)
 
             foreach my $sep (@seps)
             {   next if substr($line, 0, length $sep) ne $sep;
-                next if $sep eq 'From ' && $line !~ m/ 19[789]\d| 20[012]\d/;
+
+                # Some apps fail to escape lines starting with From
+                next if $sep eq 'From ' && $line !~ m/ 19[789][0-9]| 20[0-9][0-9]/;
 
                 $file->setpos($where);
                 $msgend = $file->tell;
@@ -168,8 +173,7 @@ sub _read_stripped_lines(;$$)
         }
 
         if(@$lines && $lines->[-1] =~ s/(\r?\n)\z//)
-        {   $file->seek(-length($1), 1);
-            pop @$lines if length($lines->[-1])==0;
+        {   pop @$lines if length($lines->[-1])==0;
         }
     }
     else # File without separators.
