@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2020 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.010';
 
 use base 'Mail::Reporter';
 
+use strict;
+use warnings;
+
 use Mail::Message::Field;
 use Mail::Message::Body::Lines;
 use Mail::Message::Body::File;
@@ -442,8 +446,8 @@ sub AUTOLOAD(@)
     no strict 'refs';
     return $self->$call(@_) if $self->can($call);  # now loaded
 
-    # Try parental AUTOLOAD
-    Mail::Reporter->$call(@_);
+	# AUTOLOAD inheritance is a pain
+	confess "Method $call() is not defined for a ", ref $self;
 }   
 
 #------------------------------------------
