@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2020 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Body::Multipart;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.010';
 
 use base 'Mail::Message::Body';
 
+use strict;
+use warnings;
+
 use Mail::Message::Body::Lines;
 use Mail::Message::Part;
 
@@ -234,7 +238,7 @@ sub read($$$$)
     my $boundary   = $self->boundary;
 
     $parser->pushSeparator("--$boundary");
-    my @msgopts    = ($self->logSettings);
+    my @msgopts    = $self->logSettings;
 
     my $te;
     $te = lc $1
