@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2020 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Field;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.010';
 
 use base 'Mail::Reporter';
 
+use strict;
+use warnings;
+
 use Carp;
 use Mail::Address;
 use Date::Format 'strftime';
@@ -135,8 +139,9 @@ sub body()
     my $body = $self->unfoldedBody;
     return $body unless $self->isStructured;
 
-    $body =~ s/\s*\;.*//s;
-    $body;
+    my ($first) = $body =~ m/^((?:"[^"]*"|'[^']*'|[^;])*)/;
+	$first =~ s/\s+$//;
+	$first;
 }
 
 
@@ -391,9 +396,15 @@ sub stringifyData($)
           my $group = Mail::Message::Field::AddrGroup->coerce($obj);
           push @addr, $group->string if $group;
       }
+      elsif($obj->isa('Mail::Message::Field'))
+      {
+          my $folded = join ' ', $obj->foldedBody;
+          $folded =~ s/^ //;
+          $folded =~ s/\n\z//;
+          push @addr, $folded;
+      }
       else
-      {    # any other object is stringified
-           push @addr, "$obj";
+      {   push @addr, "$obj";    # any other object is stringified
       }
    }
 
