@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2020 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Field::Addresses;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.010';
 
 use base 'Mail::Message::Field::Structured';
 
+use strict;
+use warnings;
+
 use Mail::Message::Field::AddrGroup;
 use Mail::Message::Field::Address;
 use List::Util 'first';
@@ -187,8 +191,16 @@ sub produceBody()
 sub consumeAddress($@)
 {   my ($self, $string, @options) = @_;
 
-    my ($local, $shorter, $loccomment) = $self->consumeDotAtom($string);
-    $local =~ s/\s//g if defined $local;
+    my ($local, $shorter, $loccomment);
+    if($string =~ s/^\s*"((?:\\.|[^"])*)"\s*\@/@/)
+    {   # local part is quoted-string rfc2822
+        ($local, $shorter) = ($1, $string);
+        $local =~ s/\\"/"/g;
+    }
+    else
+    {   ($local, $shorter, $loccomment) = $self->consumeDotAtom($string);
+        $local =~ s/\s//g if defined $local;
+    }
 
     return (undef, $string)
         unless defined $local && $shorter =~ s/^\s*\@//;
