@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2020 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use warnings;
-use strict;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Field::Date;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.010';
 
 use base 'Mail::Message::Field::Structured';
 
+use warnings;
+use strict;
+
 use POSIX qw/mktime tzset/;
 
 
@@ -29,7 +33,7 @@ sub parse($)
            (?: ($dayname) \s* \, \s* )?
            ( 0?[1-9] | [12][0-9] | 3[01] ) \s*    # day
            \s+ ( [A-Z][a-z][a-z]|[0-9][0-9] ) \s+ # month
-           ( 19[0-9][0-9] | 2[0-9]{3} ) \s+       # year
+           ( (?: 19 | 20 | ) [0-9][0-9] ) \s+     # year
                   ( [0-1]?[0-9] | 2[0-3] ) \s*    # hour
                [:.] ( [0-5][0-9] ) \s*            # minute
            (?: [:.] ( [0-5][0-9] ) )? \s+         # second
